( cd usr/lib ; rm -rf libgtk-vnc-1.0.so )
( cd usr/lib ; ln -sf libgtk-vnc-1.0.so.0.0.1 libgtk-vnc-1.0.so )
( cd usr/lib ; rm -rf libgtk-vnc-1.0.so.0 )
( cd usr/lib ; ln -sf libgtk-vnc-1.0.so.0.0.1 libgtk-vnc-1.0.so.0 )
